public inbox for development@lists.ipfire.org
 help / color / mirror / Atom feed
* [PATCH 1/3] downloadsource.sh: Change checksum algorithm to BLAKE2
@ 2022-04-08 15:10 Peter Müller
  2022-04-08 15:10 ` [PATCH 2/3] installer: Update translation message Peter Müller
  0 siblings, 1 reply; 7+ messages in thread
From: Peter Müller @ 2022-04-08 15:10 UTC (permalink / raw)
  To: development

[-- Attachment #1: Type: text/plain, Size: 1993 bytes --]

Reported-by: Arne Fitzenreiter <arne.fitzenreiter(a)ipfire.org>
Signed-off-by: Peter Müller <peter.mueller(a)ipfire.org>
---
 src/installer/downloadsource.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/installer/downloadsource.sh b/src/installer/downloadsource.sh
index c74f9e232..47086b2b7 100644
--- a/src/installer/downloadsource.sh
+++ b/src/installer/downloadsource.sh
@@ -2,7 +2,7 @@
 ###############################################################################
 #                                                                             #
 # IPFire.org - A linux based firewall                                         #
-# Copyright (C) 2010  IPFire Team  <info(a)ipfire.org>                          #
+# Copyright (C) 2007-2022  IPFire Team  <info(a)ipfire.org>                     #
 #                                                                             #
 # This program is free software: you can redistribute it and/or modify        #
 # it under the terms of the GNU General Public License as published by        #
@@ -48,17 +48,17 @@ if ! download -O "${OUTPUT}" "${URL}"; then
 	exit 1
 fi
 
-# Download went well. Checking for MD5 sum
-if download -O "${OUTPUT}.md5" "${URL}.md5" &>/dev/null; then
+# Download went well. Checking for BLAKE2 sum
+if download -O "${OUTPUT}.b2" "${URL}.b2" &>/dev/null; then
 	# Read downloaded checksum
-	read -r md5sum rest < "${OUTPUT}.md5"
-	rm -f "${OUTPUT}.md5"
+	read -r b2sum rest < "${OUTPUT}.b2"
+	rm -f "${OUTPUT}.b2"
 
 	# Compute checkum of downloaded image file
-	read -r md5sum_image rest <<< "$(md5sum "${OUTPUT}")"
+	read -r b2sum_image rest <<< "$(b2sum "${OUTPUT}")"
 
-	if [ "${md5sum}" != "${md5sum_image}" ]; then
-		echo "MD5 sum mismatch: ${md5sum} != ${md5sum_image}" >&2
+	if [ "${b2sum}" != "${b2sum_image}" ]; then
+		echo "BLAKE2 checksum mismatch: ${b2sum} != ${b2sum_image}" >&2
 		exit 2
 	fi
 fi
-- 
2.34.1

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2022-04-24 10:11 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-04-08 15:10 [PATCH 1/3] downloadsource.sh: Change checksum algorithm to BLAKE2 Peter Müller
2022-04-08 15:10 ` [PATCH 2/3] installer: Update translation message Peter Müller
2022-04-08 15:11   ` [PATCH 3/3] backupiso: Change checksum algorithm to BLAKE2 Peter Müller
2022-04-11  8:11   ` [PATCH 2/3] installer: Update translation message Michael Tremer
2022-04-12 14:58     ` Peter Müller
2022-04-12 16:24       ` Michael Tremer
2022-04-24 10:11         ` Peter Müller

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox